# doGRM.r

library('ltm')
load('itemdataset.Rdata')

# estimate GRM model
fit = grm(ddd,start.val="random")

# inspect some items and infer the sign of the latent dimension
plot(fit,type="ICC",item=c(3,24))
latentsign = sign(fit$coefficients$b3[4]);

# notice that totality of information approximately equals
print('mBDI total information')
print(information(fit,c(-10,10),item=c(1:21)))
print('BDI-II total information')
print(information(fit,c(-10,10),item=c(22:42)))

# plot the manuscript figure
dev.new()
a1 = matrix(0,1,200)
x1 = seq(-4,8,length.out=201)
for (i in 1:200) {
  a1[i] = information(fit,c(x1[i],x1[i+1]),item=c(22:42))[[1]]
}

a2 = matrix(0,1,200)
x2 = seq(-4,8,length.out=201)
for (i in 1:200) {
  a2[i] = information(fit,c(x2[i],x2[i+1]),item=c(1:21))[[1]]
}

sco = factor.scores(fit)
den <- density(sco[["score.dat"]][,45])

xrange = c(x1[2],8); yrange = c(0,1.2);
# invert xrange for correct latent sign/orientation if needed
plot(latentsign*xrange,yrange,type="n",ylab="Information",
xlab="Less depressed < - > More depressed", main="Test Information")
linetype <- c(1,2,3)
plotchar <- seq(18,18+2,1)
lines(latentsign*x1[2:201], a1, type="l", lwd=1.5,
    lty=linetype[1])
lines(latentsign*x2[2:201], a2, type="l", lwd=1.5,
    lty=linetype[2])    
lines(latentsign*den$x, den$y/max(den$y), type="l", lwd=1,
    lty=linetype[3])
legend(6, yrange[2], c('BDI-II','mBDI'), cex=0.8,
   lty=linetype, title="Scale")


print('Observe the bad overall fit on the marginals')
margins(fit)